@@ -3,7 +3,7 @@ import re
 import logging
 import glob
 from pathlib import Path
-from pds_github_util.release.snapshot_release import snapshot_release_publication
+from pds_github_util.release.release import snapshot_release_publication
 
 logging.basicConfig(level=logging.DEBUG)
 logger = logging.getLogger(__name__)
