@@ -7,7 +7,7 @@ from pds_github_util.tags.tags import Tags
 logging.basicConfig(level=logging.DEBUG)
 logger = logging.getLogger(__name__)
 
-GITHUB_TOKEN = os.environ.get("GITHUB_TOKEN")
+GITHUB_TOKEN = os.environ.get("GITHUB_TOKEN") or os.environ.get("ADMIN_GITHUB_TOKEN")
 
 
 class MyTestCase(unittest.TestCase):
